#!/usr/bin/perl -Tw

#######################################################
#
# Family Tree generation program, v2.0
# Written by Ferenc Bodon and Simon Ward, March 2000 (simonward.com)
# Copyright (C) 2000 Ferenc Bodon, Simon K Ward
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# For a copy of the GNU General Public License, visit 
# http://www.gnu.org or write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
#######################################################

use strict;
use warnings;
use CGI qw(:standard);
use Set::Scalar;
use FamilyTreeDataFactory;
use TextGeneratorFactory;
use SettingsFactory;

package FamilyTreeBase;

my $q = new CGI;

sub new {
  my ($classname) = @_;
  my $self = {
    family_tree_data => undef,
    lang             => undef,
#    treeScript       => CGI::url(-relative=>1),
    treeScript       => "ftree.cgi",
    photoUrl         => "../pictures/",
    graphicsUrl      => "../graphics",
    imgwidth         => 60,
    reqLevels        => 2,
    textGenerator    => undef,
    settings         => undef,    
  };
  $self->{imgheight}        = $self->{imgwidth} * 1.5;
  $self->{family_tree_data} =
    FamilyTreeDataFactory::createFamilyTreeDataFromFile( "../tree.txt",
    "simonward", $self->{photoUrl} );
    $self->{settings} = SettingsFactory::importSettings("perl");

  return bless $self, $classname;
}

sub process_parameters ($) {
  my ($self) = @_;
  $self->{lang} = CGI::param("lang");
  $self->{lang} = "gb" unless defined $self->{lang};
  $self->{textGenerator} =
    TextGeneratorFactory::createTextGenerator( $self->{lang} );
  Person::setReverseOrder(1)
    if(defined $self->{lang} && $self->{lang} eq "hu");
  $self->{settings}{password} = CGI::param("passwd");
  $self->{settings}{password} = "" unless defined $self->{settings}{password}; 
}

sub toppage ($$){
  my ( $self, $title ) = @_;
  print $q->header( -charset => 'UTF-8' ),
     $q->start_html(-title=>$title,
                     -meta=>{http_equiv => 'Content-Type',
                         		content    => 'text/html',
                         		charset     =>'UTF-8'});
  print $q->center($q->h1($title)), "\n";
}

#######################################################
# generates the html for the end of the page
sub endpage ($) {
  my ($self) = @_;
  print $q->br, $q->hr(),"\n",$q->start_strong(),
    $q->a({-href => ${self}->{treeScript}."?type=;passwd=".$self->{settings}{password}.";lang=".$self->{lang}}, 
      $self->{textGenerator}->{Relatives}), " - \n",
    $q->a({-href => ${self}->{treeScript}."?type=faces;passwd=".$self->{settings}{password}.";lang=".$self->{lang}}, 
      $self->{textGenerator}->{Faces}), " - \n",
    $q->a({-href => ${self}->{treeScript}."?type=snames;passwd=".$self->{settings}{password}.";lang=".$self->{lang}}, 
      $self->{textGenerator}->{Surnames}), " - \n",
    $q->a({-href => ${self}->{treeScript}."?type=hpages;passwd=".$self->{settings}{password}.";lang=".$self->{lang}}, 
      $self->{textGenerator}->{Homepages}), " - \n",
    $q->a({-href => ${self}->{treeScript}."?type=emails;passwd=".$self->{settings}{password}.";lang=".$self->{lang}}, 
      $self->{textGenerator}->{Emails}), " - \n",
    $q->a({-href => ${self}->{treeScript}."?type=bdays;passwd=".$self->{settings}{password}.";lang=".$self->{lang}}, 
      $self->{textGenerator}->{Birthdays}), "\n",
    $q->end_strong(), $q->br, $q->br,"\n";
  $self->languageChooser();

  print "\n",'<script src="http://www.google-analytics.com/urchin.js" type="text/javascript">',
      '</script>',
      '<script type="text/javascript">',
      '_uacct = "UA-1237567-1";',
      'urchinTracker();',
      '</script>', "\n";
  print $q->start_i, $self->{textGenerator}->maintainer( $self->{settings}{adminName}, 
    $self->{settings}{adminEmail},  $self->{settings}{adminHomepage} ), $q->br,
    $self->{textGenerator}->software(), "\n",
    $q->end_i, $q->br;
  if ( $self->{settings}{sitemeter_needed} ) {
    print "<!--WEBBOT bot=\"HTMLMarkup\" startspan ALT=\"Site Meter\" -->\n",
      "<script type=\"text/javascript\" language=\"JavaScript\">var site=\"$self->{settings}{sitemeter_id}\"</script>\n",
      "<script type=\"text/javascript\" language=\"JavaScript1.2\" src=\"http://s22.sitemeter.com/js/counter.js?site=$self->{settings}{sitemeter_id}\">\n",
      "</script>\n",
      "<noscript>\n",
      "<a href=\"http://s22.sitemeter.com/stats.asp?site=$self->{settings}{sitemeter_id}\" target=\"_top\">\n",
      "<img src=\"http://s22.sitemeter.com/meter.asp?site=$self->{settings}{sitemeter_id}\" alt=\"Site Meter\" border=\"0\"/></a>\n",
      "</noscript>\n",
      "<!-- Copyright (c)2005 Site Meter -->\n",
      "<!--WEBBOT bot=\"HTMLMarkup\" Endspan -->\n";
  }
  print $q->end_html;
}

#########################################################
# check password
sub password_check ($) {
  my ($self) = @_;
  if ( $self->{settings}{passwordReq} ne ""
    && $self->{settings}{password} ne $self->{settings}{passwordReq} )
  {
    $self->toppage( $self->{textGenerator}->{Error} );
    printf "<br>\n<br/>\n" . $self->{textGenerator}->{Sorry} . "!<br><br>\n";
    if ( $self->{settings}{password} eq "" ) {
      print $self->{textGenerator}->{Passwd_need};
    }
    else {
      print "You have given the wrong password for these pages.";
    }

    print "<br><form action=\"$self->{treeScript}\" method=\"GET\">",
      "<input type=\"hidden\" name=\"type\" value=\"$self->{pagetype}\">",
      "<p><strong>$self->{settings}{passwordPrompt}</strong><br>",
      "<input type=\"text\" size=\"25\" name=\"password\">",
      " <input type=\"submit\" value=\"Go\"></p>",
      "</form>\n";
    $self->endpage();
    exit 1;
  }
}

  sub getCellBgColor ($$$$){
    my ( $self, $person, $nr_of_man, $nr_of_woman ) = @_;
    if ( !defined $person->{gender} ) {
      return $self->{settings}{undef_color};
    }
    elsif ( $person->{gender} == 0 ) {
      ++$$nr_of_man;
      return $self->{settings}{man_color};
    }
    else {
      ++$$nr_of_woman;
      return $self->{settings}{woman_color};
    }
  }
  
  sub languageChooser {
    #I guess this function can be done simpler!
    my ( $self) = @_;
    my $anchor= $self->{treeScript}."?";
    my %params = CGI::Vars();
    while( my ($key, $value) = each %params) {
      if($key ne "lang") {
        $anchor .= $key."=".$value.";";
      }
      
    }
    print "\n", $q->start_table({-cellpadding => '3'}),"\n", $q->start_Tr;
    my %langToPict = TextGeneratorFactory::getLangToPict();
    while ( my ($lang, $pic) = each(%langToPict) ) {
      print $q->td({-align => "center"}, 
        $q->a({-href => "${anchor}lang=".$pic,
               -title => $self->{textGenerator}->{$lang} },
          $q->img({-width => 40, -src =>"$self->{graphicsUrl}/flags/".$pic.".gif", 
               -alt =>$self->{textGenerator}->{$lang}}))),"\n",
    }
    print $q->end_Tr, "\n", $q->end_table, $q->br,"\n";
  }
  
  sub html_img {
  my ( $self, $person ) = @_;
  if ( !defined $person ) {
    return "";
  }
  else {
    my $picture_file;
    if ( defined $person->{picture_file} ) {
      $picture_file = $self->{photoUrl} . $person->{picture_file};
    }
    else {
      $picture_file = $self->{graphicsUrl} . "/nophoto.gif";
    }
    my $img_txt = $q->img(
      {
        -border => "2",
        -src    => $picture_file,
        -alt    => $person->full_name(),
        -width  => $self->{imgwidth},
        -height => $self->{imgheight}
      }
    );
    if ( $person eq $self->{target_person} || $person == $self->{NONE_person} )
    {
      return $img_txt;
    }
    else {
      return $self->aref_tree($img_txt, $person);
    }
  }
}
  
  
  sub aref_tree {
  my ( $self, $to_ref, $person, $levels ) = @_;
  if(!defined $levels) {
    $levels = $self->{reqLevels};
    $person = $self->$self->{target_person} unless(defined $person);
  } 
  return $q->a(
        {
          -href => "$self->{treeScript}?type=tree;"
            ."target=$person->{id};levels=$levels;"
            ."passwd=$self->{password};lang=$self->{lang}",
            -title => $self->brief_info($person)            
        }, $to_ref);
  }
sub brief_info {
  my ( $self, $person ) = @_;
  my $brief_info;
  $brief_info .= $self->{textGenerator}->{father}.": ".$person->{father}->full_name()." "
    if(defined $person->{father});
  $brief_info .= $self->{textGenerator}->{mother}.": ".$person->{mother}->full_name()." "
    if(defined $person->{mother});
  $brief_info .= $self->{textGenerator}->{date_of_birth}.": ".$person->{date_of_birth}." "
    if(defined $person->{date_of_birth});
	$brief_info .= $self->{textGenerator}->{date_of_death}.": ".$person->{date_of_death}." "
	 if(defined $person->{date_of_death});
	 return $brief_info;
}
      
1;
